let sat_ai_sending = true;
const sat_ai_events = new Object();
let sat_session_id = "";
jQuery(document).ready(() => {
    // Initialize Events - only if event_names were provided
    if(typeof(sat_ai_vars["event_names"]) !== "undefined"){
        sat_ai_vars["event_names"].forEach((eventname) => {
            sat_ai_events[eventname] = new Event(eventname);
        });
    }
    // prevent any changes to this object
    Object.freeze(sat_ai_events);
    
    // Wait till Document is usable
    jQuery('.sat-bot-container').css({ "display": "block" }); // make it visible

    jQuery('#submit-icon').on('click', function () {
        jQuery("#submit_prompt").submit();
    })

    jQuery("#submit_prompt").submit(function (e) {
        e.preventDefault();
        if (sat_ai_sending) {
            return;
        }
        sat_ai_sending = true;

        let chat = jQuery("#sat-bot-messages");
        let input = jQuery("#prompt").val();
        let parser = new DOMParser();
        let data = parser.parseFromString(input, 'text/html');
        let prompt = data.body.innerText;

        let password = jQuery("#password").val();
        let write_animation = jQuery(".sat_typing");
        jQuery("#prompt").val('');
        if (prompt.length > 0) {
            chat.append("<div class='sat-bot-user chat-box-body-send'><p>" + prompt + "</p><span>" + get_current_time() + "</span></div>");
            scrollToLatest();
            write_animation.css({
                "visibility": "visible"
            });
            jQuery.ajax({
                type: 'POST',
                dataType: 'json',
                url: sat_ai_vars.AJAXUrl,
                data: {
                    action: 'sat_ai_create_ChatCompletion',
                    prompt: prompt,
                    page: sat_ai_vars.postID,
                    password: password,
                    session_id: sat_session_id,
                    nonce: sat_ai_vars.nonce,
                },
                success: function (data, textStatus, XMLHttpRequest) {
                    if (data.result) {
                        data.answers.forEach((answer) => {
                            chat.append("<div class='sat-bot-assistant chat-box-body-receive'><p>" + answer.message.value + "</p><span>" + get_current_time() + "</span></div>");
                        });
                        sat_session_id = data.session_id;
                        raise_sat_ai_events(data.raise_events);
                    } else {
                        chat.children()[chat.children().length - 1].remove();
                        chat.append("<div class='chat-box-body-receive sat-bot-error sat-bot-error'><p>"+ wp.i18n.__("Error: Please try in a few minutes again.", "sat-ai") + "</p><span>" + get_current_time() + "</span></div>");
                    }
                },
                error: function (XMLHttpRequest, textStatus, errorThrown) {
                    chat.children()[chat.children().length - 1].remove();
                    chat.append("<div class='chat-box-body-receive sat-bot-error sat-bot-error'><p>" +  wp.i18n.__("Error: Your request could not be processed. Please try in a few minutes again.", "sat-ai") + "</p><span>" + get_current_time() + "</span></div>");
                },
                complete: function (XMLHttpRequest, status) {
                    // submit_button.prop('disabled', false);
                    write_animation.css({
                        "visibility": "hidden"
                    });
                    scrollToLatest();
                    sat_ai_sending = false;
                }
            });
        } else {
            if (input.length > 0) {
                chat.append("<div class='chat-box-body-receive sat-bot-error sat-bot-error'><p>" + wp.i18n.__("Error: Please enter a valid message.", "sat-ai") + "</p><span>" + get_current_time() + "</span></div>");
                scrollToLatest();
            }
            sat_ai_sending = false;
        }
    });

    jQuery.ajax({
        type: 'POST',
        dataType: 'json',
        url: sat_ai_vars.AJAXUrl,
        data: {
            action: 'sat_ai_get_chatHistory',
            nonce: sat_ai_vars.nonce,
        },
        success: function (data, textStatus, XMLHttpRequest) {
            let chat = jQuery("#sat-bot-messages");
            chat.children().remove()
            data.forEach(message => {
                if (message.role == "user") {
                    chat.append("<div class='sat-bot-user chat-box-body-send'><p>" + message.content + "</p><span></span></div>");
                }
                if (message.role == "assistant") {
                    chat.append("<div class='sat-bot-assistant chat-box-body-receive'><p>" + message.content + "</p><span></span></div>");
                }
            });

        },
        error: function (XMLHttpRequest, textStatus, errorThrown) {
            chat.children()[chat.children().length - 1].remove();
            chat.append("<div class='chat-box-body-receive sat-bot-error sat-bot-warning'><p>" + wp.i18n.__("Warning: Your chat history could not be loaded.", "sat-ai") + "</p><span>" + get_current_time() + "</span></div>");

        },
        complete: function (XMLHttpRequest, status) {
            scrollToLatest();
            sat_ai_sending = false;
        }
    });

    // Adjust Code
    jQuery('.chat-button').on('click', showChat);
    jQuery('#sat-attract').on('click', showChat);

    jQuery('.sat-bot-opened-container .sat-bot-header p').on('click', function () {
        jQuery('.chat-button').css({ "display": "block" });
        jQuery('.sat-bot-opened-container').css({ "display": "none" });
    })

    // Makes an Enter submit the form, on shift+enter new line
    jQuery("#prompt").keypress(function (e) {
        if (e.which === 13 && !e.shiftKey) {
            e.preventDefault();

            jQuery(this).closest("form").submit();
        }
    });

    showChat();

});

// Function to raise all Events of a given array
function raise_sat_ai_events(event_names){
    if(typeof(event_names) == "object"){
        event_names.forEach((event_name =>{
            if (sat_ai_events[event_name] !== undefined){
                document.dispatchEvent(sat_ai_events[event_name]);
            }
        }));
    }
}

function showChat() {
    jQuery('.chat-button').css({
        "display": "none"
    });
    jQuery("#sat-attract").removeClass('sat-show');
    jQuery('.sat-bot-opened-container').css({
        "display": "block"
    });

    document.querySelector("#prompt").focus();
}

function scrollToLatest() {
    let chat = jQuery("#sat-bot-messages");
    chat.children()[chat.children().length - 1].scrollIntoView({ behavior: "smooth" });
}

function get_current_time() {
    let now = new Date();
    let time = String(now.getHours()).padStart(2, 0) + ":" + String(now.getMinutes()).padStart(2, 0) + ":" + String(now.getSeconds()).padStart(2, 0);
    return time;
}