<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              http://www.saticon.de
 * @since             0.0.1
 * @package           Satbot
 *
 * @wordpress-plugin
 * Plugin Name:       Sat-AI
 * Plugin URI:        https://www.saticon.de
 * Description:       This is a plugin written by Saticon GmbH, which implements a Chatbot powered by OpenAI GPT. It allows you to use the current Assistant API from OpenAI, with the possibility to add your own tools/functions which the Chatbot can call upon.
 * Version:           1.0.0
 * Author:            Saticon
 * Author URI:        http://www.saticon.de
 * License:           GPL-3.0+
 * License URI:       http://www.gnu.org/licenses/gpl-3.0.txt
 * Text Domain:       sat-ai
 * Domain Path: /languages
 */

// If this file is called directly, abort.
if (!defined('WPINC')) {
    die;
}

define('SAT_AI_VERSION', '1.0.0');
define('SAT_AI', plugin_basename(dirname(__FILE__)));
define('SAT_AI_PLUGIN_URL', plugin_dir_url(__FILE__));
define('SAT_AI_PLUGIN_PATH', plugin_dir_path(__FILE__));
define('SAT_AI_PLUGIN_LANGUAGES_PATH_PHP', dirname(plugin_basename(__FILE__)) . '/languages/');
define('SAT_AI_PLUGIN_LANGUAGES_PATH_JS', plugin_dir_path(__FILE__) . 'languages/');

require_once(plugin_dir_path(__FILE__) . "vendor/autoload.php");
include_once(plugin_dir_path(__FILE__) . "templates/class-sat-ai.php");
include_once(plugin_dir_path(__FILE__) . "templates/class-sat-ai-handler.php");
include_once(plugin_dir_path(__FILE__) . "templates/functions.php");
include_once(plugin_dir_path(__FILE__) . "templates/functions-assistant.php");
include_once(plugin_dir_path(__FILE__) . "templates/functions-versionizing.php");
include_once(plugin_dir_path(__FILE__) . "templates/ajax.php");
include_once(plugin_dir_path(__FILE__) . "templates/views/chat_bot.php");

// chat verlauf
include_once(plugin_dir_path(__FILE__) . "templates/class-sat-ai-chatverlauf.php");

function activate_sat_ai()
{
    sat_ai_create_chat_table();
    sat_ai_create_message_table();
    add_sat_role_capabilities();
    flush_rewrite_rules();
}

function deactivate_sat_ai()
{
    // Clean up on deactivation
    remove_sat_role_capabilities();
    flush_rewrite_rules();
}

function add_sat_ai_admin_scripts($hook)
{
    // only for our "Admin Menupage"
    if ($hook == "toplevel_page_sat-ai") {
        wp_enqueue_style('sat_ai_style', plugin_dir_url(__FILE__) . 'admin/css/sat_ai_setting_page.css', array(), SAT_AI_VERSION);
        
        wp_enqueue_script(
            'sat_ai_script_backend',
            plugin_dir_url(__FILE__) . 'admin/js/sat_ai.js',
            ['jquery', 'wp-i18n'],
            SAT_AI_VERSION,
            array('in_footer' => false, 'strategy' => 'defer')
        );
        wp_set_script_translations('sat_ai_script_backend', 'sat-ai', SAT_AI_PLUGIN_LANGUAGES_PATH_JS);

        wp_add_inline_script(
            'sat_ai_script_backend',
            'const sat_ai_vars = ' . wp_json_encode(
                array(
                    'AJAXUrl' => admin_url('admin-ajax.php'),
                    'nonce' => wp_create_nonce('ajax-nonce'),
                )
            )
        );
    }
    if ($hook == "sat-ai-options_page_sat-ai-chat-verlauf") {
        wp_enqueue_style('sat_ai_style', plugin_dir_url(__FILE__) . 'admin/css/sat_ai.css', array(), SAT_AI_VERSION);
        wp_enqueue_script(
            'sat_ai_script_chatverlauf',
            plugin_dir_url(__FILE__) . 'admin/js/sat_ai_chat.js',
            ['jquery', 'wp-i18n'],
            SAT_AI_VERSION,
            array('in_footer' => false, 'strategy' => 'defer')
        );
        wp_set_script_translations('sat_ai_script_chatverlauf', 'sat-ai', SAT_AI_PLUGIN_LANGUAGES_PATH_JS);

        wp_add_inline_script(
            'sat_ai_script_chatverlauf',
            'const sat_ai_vars = ' . wp_json_encode(
                array(
                    'AJAXUrl' => admin_url('admin-ajax.php'),
                    'nonce' => wp_create_nonce('ajax-nonce'),
                )
            )
        );
    }
}

function add_sat_ai_public_scripts()
{
    wp_enqueue_script(
        'sat_ai_script_public',
        plugin_dir_url(__FILE__) . 'public/js/sat_ai.js',
        ['jquery', 'wp-i18n'],
        SAT_AI_VERSION,
        array('in_footer' => false, 'strategy' => 'defer')
    );
    wp_set_script_translations('sat_ai_script_public', 'sat-ai', SAT_AI_PLUGIN_LANGUAGES_PATH_JS);
    wp_add_inline_script(
        'sat_ai_script_public',
        'const sat_ai_vars = ' . wp_json_encode(
            array(
                'AJAXUrl' => admin_url('admin-ajax.php'),
                'nonce' => wp_create_nonce('ajax-nonce'),
                'event_names' => sat_ai_get_tool_event_names(),
            )
        )
    );
}

function add_sat_ai_vars()
{
    wp_register_script('sat-placeholder-vars', '', array(), SAT_AI_VERSION, array("in_footer" => false, 'strategy' => 'defer'));
    wp_enqueue_script('sat-placeholder-vars');
    wp_add_inline_script(
        'sat-placeholder-vars',
        'const sat_ai_vars = ' . wp_json_encode(
            array(
                'AJAXUrl' => admin_url('admin-ajax.php'),
                'nonce' => wp_create_nonce('ajax-nonce'),
                'event_names' => sat_ai_get_tool_event_names(),
            )
        )
    );
}

function add_sat_ai_style()
{
    wp_enqueue_style('sat_ai_style', plugin_dir_url(__FILE__) . 'public/css/sat_ai.css', array(), SAT_AI_VERSION);
}

function sat_ai_pages()
{
    add_menu_page(
        "Sat-AI Chatbot Options",
        'Sat-AI Options',
        'manage_options',
        'sat-ai',
        'sat_ai_page',
        'dashicons-reddit'
    );

    add_submenu_page(
        'sat-ai',
        'Sat-AI Chat Verlauf',
        'Chat Verlauf',
        'manage_options',
        'sat-ai-chat-verlauf',
        'sat_ai_chatverlauf'
    );
}


register_activation_hook(__FILE__, 'activate_sat_ai');
register_deactivation_hook(__FILE__, 'deactivate_sat_ai');

function sat_ai_initialize_textdomain()
{
    load_plugin_textdomain('sat-ai', false, SAT_AI_PLUGIN_LANGUAGES_PATH_PHP);
}


function run_sat_ai()
{
    // Load text-domain and the translations
    add_action('plugins_loaded', 'sat_ai_initialize_textdomain');

    // Custom Posttype for role versionizing
    add_action('init', 'sat_versionizing');

    // Admin Menu
    add_action('admin_menu', 'sat_ai_pages', 9); // Priority of 9 required to prevent overwrite which page is loaded for Sat-AI Options Menu Band

    // sanity update role if role_post is changed
    add_action('transition_post_status', 'sat_role_unpublished', 10, 3);
    add_action('save_post_sat_role', 'sat_role_updated', 10, 2);
    
    // JS Script Front/Backend, needed for AJAX
    $sat_ai_dsgvo_setting = get_option("sat_openai_dsgvo_behaviour");
    if ($sat_ai_dsgvo_setting != 1 && $sat_ai_dsgvo_setting !== false) {
        add_action('wp_enqueue_scripts', 'add_sat_ai_public_scripts');
    } else {
        add_action('wp_enqueue_scripts', 'add_sat_ai_vars');
    }
    add_action('admin_enqueue_scripts', 'add_sat_ai_admin_scripts');

    // load styles for frontend
    add_action('wp_print_styles', 'add_sat_ai_style');
    // Add Chatbot to the frontend.
    add_action('wp_footer', 'sat_ai_render_chatbot'); // last body

    // AJAX Actions create_ChatCompletion
    add_action('wp_ajax_sat_ai_create_ChatCompletion', 'sat_ai_create_ChatCompletion');
    add_action('wp_ajax_nopriv_sat_ai_create_ChatCompletion', 'sat_ai_create_ChatCompletion');
    add_action('wp_ajax_sat_ai_get_chatHistory', 'sat_ai_get_chatHistory');
    add_action('wp_ajax_nopriv_sat_ai_get_chatHistory', 'sat_ai_get_chatHistory');
    add_action('wp_ajax_sat_ai_get_Chat', 'sat_ai_get_Chat');

    // Costum Post Type
    add_filter('user_can_richedit', "sat_ai_disable_visual_editor");
}

run_sat_ai();
