<?php

function sat_ai_page()
{
    // Variables defined here are acessible by the templates
    if (!current_user_can('manage_options')) {
        wp_die(esc_html(__('Insufficent permission!', 'sat-ai')));
    }
    $action = isset($_GET['action']) ? $_GET['action'] : "api";

    $ai_role = get_option("sat_openai_role");
    $models = sat_ai_get_models();
    $assistant_id = get_option("sat_openai_assistant");
    if (!$models) {
        $models = (object) array();
        $models->data = (object) array();
    }

?>
    <div class="wrap sat-ai-setting-page">
        <?php if ($models->data == new stdClass()) : ?>
            <div class="notice notice-warning">
                <p><?php echo esc_html_e("Please enter a valid OpenAI API key.", "sat-ai") ?></p>
            </div>
        <?php endif; ?>
        <?php if ($ai_role == 0 || $ai_role === false) : ?>
            <div class="notice notice-error">
                <p><?php echo esc_html_e("Please create and/or select a role for your Chatbot.", "sat-ai"); ?></p>
            </div>
        <?php endif; ?>
        <?php if ($assistant_id == 0 || $assistant_id === false || empty($assistant_id)) : ?>
            <div class="notice notice-error">
                <p><?php esc_html_e("Please enter a valid Assistant ID", "sat-ai") ?></p>
            </div>
        <?php endif; ?>
        <?php if (array_key_exists('error', $_GET)) : ?>
            <div class="notice notice-error">
                <p><?php echo esc_html($_GET['error']); ?></p>
            </div>
        <?php endif; ?>
        <?php if (array_key_exists('success', $_GET)) : ?>
            <div class="notice notice-success">
                <p><?php echo esc_html($_GET['success']); ?></p>
            </div>
        <?php endif; ?>
        <?php if (array_key_exists('notice', $_GET)) : ?>
            <div class="notice notice-info">
                <p><?php echo esc_html($_GET['notice']); ?></p>
            </div>
        <?php endif; ?>
        <h2><?php esc_html_e('Settings', 'sat-ai'); ?></h2>
        <div class="sat-ai-header">
            <nav>
                <a href="admin.php?page=sat-ai" class="nav-tab <?php if ($action === "api") : ?>nav-tab-active<?php endif; ?>">API</a>
                <a href="admin.php?page=sat-ai&action=general" class="nav-tab <?php if ($action === "general") : ?>nav-tab-active<?php endif; ?>"><?php esc_html_e('General', 'sat-ai'); ?></a>
                <a href="admin.php?page=sat-ai&action=chat-test" class="nav-tab <?php if ($action === "chat-test") : ?>nav-tab-active<?php endif; ?>"><?php esc_html_e('Chat test', 'sat-ai'); ?></a>
            </nav>
        </div>
        <div class="tab-content">
            <?php
            switch ($action) {
                case "general":
                    $template = dirname(__FILE__) . '/views/settings/general.php';
                    break;
                case "api":
                    $template = dirname(__FILE__) . '/views/settings/api.php';
                    break;
                case "chat-test":
                    $template = dirname(__FILE__) . '/views/settings/chat-test.php';
                    break;
                default:
                    $template = dirname(__FILE__) . '/views/settings/api.php';
                    break;
            }

            if (file_exists($template)) {
                include $template;
            }
            ?>
        </div>
    </div>
<?php
}
