<?php

function sat_versionizing()
{
    register_post_type(
        'sat_role',
        array(
            "label" => "Sat-AI Rolle",
            "labels" => array(
                "name" => "Sat-AI Rolle",
                "singular_name" => "Sat-AI Rolle",
                "add_new" => "Add Sat-AI Rolle",
                "add_new_item" => "Add new Sat-AI Rolle"
            ),
            "description" => "",
            "public" => false,
            "hierarchical" => false,
            "exclude_from_search" => true,
            "publicly_queryable" => false,
            "show_ui" => true,
            "show_in_menu" => "sat-ai",
            "show_in_nav_menus" => false,
            "show_in_admin_bar" => false,
            "show_in_rest" => false,
            "capability_type" => array("sat_role", "sat_roles"),
            "map_meta_cap" => true,
            "supports" => array(
                "title", 
                "editor", 
                "revisions", 
            ),
            "has_archive" => false,
            "query_var" => false,
            "can_export" => true,
            "delete_with_user" => false,
        )
    );
}

function get_sat_openai_roles()
{
    $args = array(
        'post_type' => 'sat_role',
        'post_status' => 'publish',
        'orderby' => 'ID',
        'order' => 'ASC'
    );
    $wp_query = new WP_Query($args);
    $roles = array();

    if ($wp_query->have_posts()) {
        while ($wp_query->have_posts()) {
            $wp_query->the_post();
            $title = get_the_title();
            $id = get_the_ID();
            $roles[] = array(
                "id" => $id,
                "title" => $title,
            );
        }
    }
    wp_reset_postdata();
    return $roles;
}

function sat_role_unpublished($new_status, $old_status, $post)
{
    if ($post->post_type == "sat_role") {
        if ($old_status == 'publish'  &&  $new_status != 'publish') {
            $role_id = get_option("sat_openai_role");
            if ($post->ID == $role_id) {
                update_option("sat_openai_role", 0);
            }
        }
    }
}

function sat_role_updated($post_id, $post)
{
    // Do not update openai role on autosave
    if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
        return;
    }
    // our post_type
    if ($post->post_type == "sat_role") {
        // selected post as role
        $role_id = get_option("sat_openai_role");
        if ($post_id == $role_id) {
            // if yes, update api
            sat_modify_assistant_parameters(array(
                "instructions" => $post->post_content,
            ));
        }
    }
}

function sat_ai_disable_visual_editor($default)
{
    // Disable any Editor except Text/HTML for the custom post type
    if (get_post_type() === 'sat_role') {
        return false;
    }
    return $default;
}

function add_sat_role_capabilities()
{
    $role = get_role('administrator');
    $capabilities = array(
        'edit_sat_roles',
        'edit_others_sat_roles',
        'delete_sat_roles',
        'publish_sat_roles',
        'read_private_sat_roles',
        'delete_private_sat_roles',
        'delete_published_sat_roles',
        'delete_others_sat_roles',
        'edit_private_sat_roles',
        'edit_published_sat_roles',
    );
    foreach ($capabilities as $cap) {
        $role->add_cap($cap);
    }
}
function remove_sat_role_capabilities()
{
    $role = get_role('administrator');
    $capabilities = array(
        'edit_sat_roles',
        'edit_others_sat_roles',
        'delete_sat_roles',
        'publish_sat_roles',
        'read_private_sat_roles',
        'delete_private_sat_roles',
        'delete_published_sat_roles',
        'delete_others_sat_roles',
        'edit_private_sat_roles',
        'edit_published_sat_roles',
    );
    foreach ($capabilities as $cap) {
        $role->remove_cap($cap);
    }
}